# EzPyPI

A Python publication tool for painlessly uploading your package to GitHub, Test PyPI, and PyPI.

## A step-by-step tutorial for starting a Python project

> [EzPyPI](https://zacks.one/ezpypi)

---

## Usage

